@@ -1,29 +1,25 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 import datetime
 
-from openpyxl.compat import safe_string
-from openpyxl.utils.datetime import (
-    CALENDAR_WINDOWS_1900,
-    to_ISO8601,
-    from_ISO8601,
-)
 from openpyxl.descriptors import (
-    String,
     DateTime,
     Alias,
-    )
+)
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors.nested import NestedText
-from openpyxl.xml.functions import (Element, QName, tostring)
+from openpyxl.xml.functions import (
+    Element,
+    QName,
+)
 from openpyxl.xml.constants import (
     COREPROPS_NS,
     DCORE_NS,
     XSI_NS,
     DCTERMS_NS,
-    DCTERMS_PREFIX
 )
 
+
 class NestedDateTime(DateTime, NestedText):
 
     expected_type = datetime.datetime
@@ -34,7 +30,7 @@ class NestedDateTime(DateTime, NestedText):
             tagname = "{%s}%s" % (namespace, tagname)
         el = Element(tagname)
         if value is not None:
-            el.text = to_ISO8601(value)
+            el.text = value.isoformat(timespec="seconds") + 'Z'
             return el
 
 
@@ -78,9 +74,9 @@ class DocumentProperties(Serialisable):
     modified = QualifiedDateTime(allow_none=True, namespace=DCTERMS_NS)
 
     __elements__ = ("creator", "title", "description", "subject","identifier",
-                  "language", "created", "modified", "lastModifiedBy", "category",
-                  "contentStatus", "version", "revision", "keywords", "lastPrinted",
-                  )
+                    "language", "created", "modified", "lastModifiedBy", "category",
+                    "contentStatus", "version", "revision", "keywords", "lastPrinted",
+                    )
 
 
     def __init__(self,
@@ -91,12 +87,12 @@ class DocumentProperties(Serialisable):
                  lastPrinted=None,
                  revision=None,
                  version=None,
-                 created=datetime.datetime.now(),
+                 created=datetime.datetime.utcnow(),
                  creator="openpyxl",
                  description=None,
                  identifier=None,
                  language=None,
-                 modified=datetime.datetime.now(),
+                 modified=datetime.datetime.utcnow(),
                  subject=None,
                  title=None,
                  ):
