@@ -1,6 +1,5 @@
-# Copyright (c) 2010-2020 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
-import posixpath
 from warnings import warn
 
 from openpyxl.xml.functions import fromstring
@@ -10,16 +9,13 @@ from openpyxl.packaging.relationship import (
     get_rels_path,
     get_rel,
 )
-from openpyxl.packaging.manifest import Manifest
 from openpyxl.packaging.workbook import WorkbookPackage
 from openpyxl.workbook import Workbook
-from openpyxl.workbook.defined_name import (
-    _unpack_print_area,
-    _unpack_print_titles,
-)
+from openpyxl.workbook.defined_name import DefinedNameList
 from openpyxl.workbook.external_link.external import read_external_link
 from openpyxl.pivot.cache import CacheDefinition
 from openpyxl.pivot.record import RecordList
+from openpyxl.worksheet.print_settings import PrintTitles, PrintArea
 
 from openpyxl.utils.datetime import CALENDAR_MAC_1904
 
@@ -31,6 +27,7 @@ class WorkbookParser:
     def __init__(self, archive, workbook_part_name, keep_links=True):
         self.archive = archive
         self.workbook_part_name = workbook_part_name
+        self.defined_names = DefinedNameList()
         self.wb = Workbook()
         self.keep_links = keep_links
         self.sheets = []
@@ -57,7 +54,7 @@ class WorkbookParser:
         self.wb.calculation = package.calcPr
         self.caches = package.pivotCaches
 
-        #external links contain cached worksheets and can be very big
+        # external links contain cached worksheets and can be very big
         if not self.keep_links:
             package.externalReferences = []
 
@@ -68,8 +65,8 @@ class WorkbookParser:
             )
 
         if package.definedNames:
-            package.definedNames._cleanup()
-            self.wb.defined_names = package.definedNames
+            #package.definedNames._cleanup()
+            self.defined_names = package.definedNames
 
         self.wb.security = package.workbookProtection
 
@@ -84,7 +81,7 @@ class WorkbookParser:
 
         for sheet in self.sheets:
             if not sheet.id:
-                msg = "File contains an invalid specification for {0}. This will be removed".format(sheet.name)
+                msg = f"File contains an invalid specification for {0}. This will be removed".format(sheet.name)
                 warn(msg)
                 continue
             yield sheet, self.rels[sheet.id]
@@ -92,24 +89,36 @@ class WorkbookParser:
 
     def assign_names(self):
         """
-        Bind reserved names to parsed worksheets
+        Bind defined names and other definitions to worksheets or the workbook
         """
-        defns = []
 
-        for defn in self.wb.defined_names.definedName:
-            reserved = defn.is_reserved
-            if reserved in ("Print_Titles", "Print_Area"):
-                sheet = self.wb._sheets[defn.localSheetId]
-                if reserved == "Print_Titles":
-                    rows, cols = _unpack_print_titles(defn)
-                    sheet.print_title_rows = rows
-                    sheet.print_title_cols = cols
+        for idx, names in self.defined_names.by_sheet().items():
+            if idx == "global":
+                self.wb.defined_names = names
+                continue
+
+            try:
+                sheet = self.wb._sheets[idx]
+            except IndexError:
+                warn(f"Defined names for sheet index {idx} cannot be located")
+                continue
+
+            new_names = {}
+            for name, defn in names.items():
+                reserved = defn.is_reserved
+                if reserved is None:
+                    new_names[name] = defn
+
+                elif reserved == "Print_Titles":
+                    titles = PrintTitles.from_string(defn.value)
+                    sheet._print_rows = titles.rows
+                    sheet._print_cols = titles.cols
                 elif reserved == "Print_Area":
-                    sheet.print_area = _unpack_print_area(defn)
-            else:
-                defns.append(defn)
-        self.wb.defined_names.definedName = defns
-
+                    try:
+                        sheet._print_area = PrintArea.from_string(defn.value)
+                    except TypeError:
+                        warn(f"Print area cannot be set to Defined name: {defn.value}.")
+                        continue
 
     @property
     def pivot_caches(self):
@@ -122,5 +131,5 @@ class WorkbookParser:
             if cache.deps:
                 records = get_rel(self.archive, cache.deps, cache.id, RecordList)
                 cache.records = records
-            d[c.cacheId]  = cache
+            d[c.cacheId] = cache
         return d
