@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2020 openpyxl
+# Copyright (c) 2010-2023 openpyxl
 
 """Write a .xlsx file."""
 
@@ -16,6 +16,7 @@ from openpyxl.xml.constants import (
     ARC_ROOT_RELS,
     ARC_WORKBOOK_RELS,
     ARC_APP, ARC_CORE,
+    ARC_CUSTOM, CPROPS_TYPE,
     ARC_THEME,
     ARC_STYLE,
     ARC_WORKBOOK,
@@ -72,6 +73,16 @@ class ExcelWriter(object):
         else:
             archive.writestr(ARC_THEME, theme_xml)
 
+        if len(self.workbook.custom_doc_props) >= 1:
+            archive.writestr(ARC_CUSTOM, tostring(self.workbook.custom_doc_props.to_tree()))
+            class CustomOverride():
+                path = "/" + ARC_CUSTOM #PartName
+                mime_type = CPROPS_TYPE #ContentType
+
+            custom_override = CustomOverride()
+            # custom_override = Override(PartName="/docProps/custom.xml", ContentType="application/vnd.openxmlformats-officedocument.custom-properties+xml")
+            self.manifest.append(custom_override)
+
         self._write_worksheets()
         self._write_chartsheets()
         self._write_images()
@@ -292,19 +303,3 @@ def save_workbook(workbook, filename):
     writer = ExcelWriter(workbook, archive)
     writer.save()
     return True
-
-
-@deprecated("Use a NamedTemporaryFile")
-def save_virtual_workbook(workbook):
-    """Return an in-memory workbook, suitable for a Django response."""
-    tmp = TemporaryFile()
-    archive = ZipFile(tmp, 'w', ZIP_DEFLATED, allowZip64=True)
-
-    writer = ExcelWriter(workbook, archive)
-    writer.save()
-
-    tmp.seek(0)
-    virtual_workbook = tmp.read()
-    tmp.close()
-
-    return virtual_workbook
